@@ -235,7 +235,7 @@ gtk_tree_store_init (GtkTreeStore *tree_store)
   while (tree_store->stamp == 0);
 
   tree_store->sort_list = NULL;
-  tree_store->sort_column_id = -2;
+  tree_store->sort_column_id = GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID;
   tree_store->columns_dirty = FALSE;
 }
 
@@ -276,6 +276,7 @@ gtk_tree_store_new (gint n_columns,
 	{
 	  g_warning ("%s: Invalid type %s\n", G_STRLOC, g_type_name (type));
 	  g_object_unref (retval);
+          va_end (args);
 	  return NULL;
 	}
       gtk_tree_store_set_column_type (retval, i, type);
@@ -1070,6 +1071,7 @@ gtk_tree_store_set_valist (GtkTreeStore *tree_store,
  * The list is terminated by a -1. For example, to set column 0 with type
  * %G_TYPE_STRING to "Foo", you would write 
  * <literal>gtk_tree_store_set (store, iter, 0, "Foo", -1)</literal>.
+ * The value will be copied or referenced by the store if appropriate.
  **/
 void
 gtk_tree_store_set (GtkTreeStore *tree_store,
